==> google-cloud-sdk-290.0.1.tgz: google-cloud-sdk/lib/surface/compute/routers/get_status.py <==
# -*- coding: utf-8 -*- #
# Copyright 2015 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Command for getting the status of Google Compute Engine routers."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.compute import base_classes
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.compute import flags as compute_flags
from googlecloudsdk.command_lib.compute.routers import flags


class Describe(base.DescribeCommand):
  """Get status of a Google Compute Engine router.

  *{command}* displays all runtime data associated with a Google Compute
  Engine router.
  """

  ROUTER_ARG = None

  @staticmethod
  def Args(parser):
    Describe.ROUTER_ARG = flags.RouterArgument()
    Describe.ROUTER_ARG.AddArgument(parser, operation_type='describe')

  def Run(self, args):
    holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
    client = holder.client

    router_ref = Describe.ROUTER_ARG.ResolveAsResource(
        args,
        holder.resources,
        scope_lister=compute_flags.GetDefaultScopeLister(client))

    request = client.messages.ComputeRoutersGetRouterStatusRequest(
        **router_ref.AsDict())

    return client.MakeRequests([(client.apitools_client.routers,
                                 'GetRouterStatus', request)])[0]

==> google-cloud-sdk-548.0.0.tgz: google-cloud-sdk/lib/surface/compute/routers/get_status.py <==
# -*- coding: utf-8 -*- #
# Copyright 2015 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Command for getting the status of Compute Engine routers."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.compute import base_classes
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.compute import flags as compute_flags
from googlecloudsdk.command_lib.compute.routers import flags


class Describe(base.DescribeCommand):
  """Get status of a Compute Engine router.

  *{command}* displays all runtime data associated with a Compute Engine
  router.
  """

  ROUTER_ARG = None

  @classmethod
  def Args(cls, parser):
    Describe.ROUTER_ARG = flags.RouterArgument()
    Describe.ROUTER_ARG.AddArgument(parser, operation_type='describe')

  def Run(self, args):
    holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
    client = holder.client

    router_ref = Describe.ROUTER_ARG.ResolveAsResource(
        args,
        holder.resources,
        scope_lister=compute_flags.GetDefaultScopeLister(client))

    request = client.messages.ComputeRoutersGetRouterStatusRequest(
        **router_ref.AsDict())

    return client.MakeRequests([(client.apitools_client.routers,
                                 'GetRouterStatus', request)])[0]
